import {
  createRouter,
  createWebHistory,
  createWebHashHistory,
} from "vue-router";
import NProgress from "@/utils/progress";
import { handleChangeHtmlFontSize } from "@/utils/common";
/** 自动导入全部静态路由，无需再手动引入！匹配 src/router/modules 目录（任何嵌套级别）中具有 .ts 扩展名的所有文件，除了 remaining.ts 文件
 * 如何匹配所有文件请看：https://github.com/mrmlnc/fast-glob#basic-syntax
 * 如何排除文件请看：https://cn.vitejs.dev/guide/features.html#negative-patterns
 */
const modules: Record<string, any> = import.meta.glob(
  ["./modules/**/*.ts", "!./modules/**/remaining.ts"],
  {
    eager: true,
  }
);
const routes = [];
Object.keys(modules).forEach((key) => {
  routes.push(
    ...(Array.isArray(modules[key].default) ? modules[key].default : [])
  );
});

console.log(routes);

const router = createRouter({
  history: createWebHashHistory(),
  routes,
  scrollBehavior(to, from, savedPosition) {
    return new Promise((resolve) => {
      if (savedPosition) {
        return savedPosition;
      } else {
        if (from.meta.saveScrollTop) {
          const top: number =
            document.documentElement.scrollTop || document.body.scrollTop;
          resolve({ left: 0, top });
        }
      }
    });
  },
});

router.beforeEach((to: ToRouteType, _from, next) => {
  NProgress.start();
  to.meta?.needService && appendCustomService();
  if (to.meta?.title) {
    document.title = to.meta?.title;
  }
  next();
});

router.afterEach((to) => {
  if (to.params?.mechanismId) {
    localStorage.setItem("mechanismId", to.params.mechanismId as string);
  }
  console.log("to", to.query);

  if (to.query?.caringMode == "open") {
    handleChangeHtmlFontSize();
  } else {
    document.documentElement.style.fontSize = "";
  }
  NProgress.done();
});

const appendCustomService = () => {
  const el = document.querySelector("#customService");
  const a = document.createElement("a");
  a.id = "customService";
  a.href = "https://work.weixin.qq.com/kfid/kfca0513e081f5317d9";
  a.style.position = "fixed";
  a.style.bottom = "20%";
  a.style.right = "20px";
  a.innerHTML = `<svg t="1697164746002" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="5127" width="48" height="48"><path d="M513 514m-425 0a425 425 0 1 0 850 0 425 425 0 1 0-850 0Z" fill="#DCEDFF" p-id="5128"></path><path d="M799.76 435.68q-4.23-13.43-9.74-26.48a297.57 297.57 0 0 0-548 0q-5.52 13.08-9.75 26.52a72.29 72.29 0 0 0-56.06 70.44v45.67a72.27 72.27 0 0 0 72.27 72.27 29 29 0 0 0 29-29v-140a21.21 21.21 0 0 0-12.69-19.42 266.8 266.8 0 0 1 502.58 0.07 21.21 21.21 0 0 0-12.54 19.35v140a29 29 0 0 0 29 29A72.27 72.27 0 0 0 856 551.83v-45.67a72.28 72.28 0 0 0-56.24-70.48z" fill="#88C4FF" p-id="5129"></path><path d="M516 297.94c-101.22 0-187 66.15-216.43 157.54v139.68c29.51 91.4 115.25 157.53 216.43 157.53h203.35a12.87 12.87 0 0 0 12.9-12.8l-43.48-66.72a226.43 226.43 0 0 0 43.62-77.71V455.24C702.85 364 617.17 297.94 516 297.94z" fill="#468EF7" p-id="5130"></path></svg>`;
  if (el) {
    el.remove();
  } else {
    document.body.appendChild(a);
  }
};
export default router;
